changeset 63720:10d4557c5555

(get_next_display_element): Finish reversing the tests of Vnobreak_char_display. (Vnobreak_char_display): Renamed from Vshow_nonbreak_escape. All uses changed. (Qnobreak_space): Renamed from Qno_break_space. All uses changed. (syms_of_xdisp): Define nobreak-char-display and nobreak-space.
author Richard M. Stallman <rms@gnu.org>
date Thu, 23 Jun 2005 21:32:26 +0000
parents c3da886cec72
children 9bcd6144b097
files src/xdisp.c
diffstat 1 files changed, 15 insertions(+), 14 deletions(-) [+]
line wrap: on
line diff
--- a/src/xdisp.c	Thu Jun 23 21:29:26 2005 +0000
+++ b/src/xdisp.c	Thu Jun 23 21:32:26 2005 +0000
@@ -320,7 +320,7 @@
 
 /* Non-nil means escape non-break space and hyphens.  */
 
-Lisp_Object Vshow_nonbreak_escape;
+Lisp_Object Vnobreak_char_display;
 
 #ifdef HAVE_WINDOW_SYSTEM
 extern Lisp_Object Voverflow_newline_into_fringe;
@@ -352,7 +352,7 @@
 
 /* Name and number of the face used to highlight non-breaking spaces.  */
 
-Lisp_Object Qno_break_space;
+Lisp_Object Qnobreak_space;
 
 /* The symbol `image' which is the car of the lists used to represent
    images in Lisp.  */
@@ -5097,7 +5097,7 @@
 		       ? ((it->c >= 127
 			   && it->len == 1)
 			  || !CHAR_PRINTABLE_P (it->c)
-			  || (!NILP (Vshow_nonbreak_escape)
+			  || (!NILP (Vnobreak_char_display)
 			      && (it->c == 0x8a0 || it->c == 0x8ad
 				  || it->c == 0x920 || it->c == 0x92d
 				  || it->c == 0xe20 || it->c == 0xe2d
@@ -5152,12 +5152,12 @@
 	      /* Handle non-break space in the mode where it only gets
 		 highlighting.  */
 
-	      if (EQ (Vshow_nonbreak_escape, Qt)
+	      if (EQ (Vnobreak_char_display, Qt)
 		  && (it->c == 0x8a0 || it->c == 0x920
 		      || it->c == 0xe20 || it->c == 0xf20))
 		{
 		  /* Merge the no-break-space face into the current face.  */
-		  face_id = merge_faces (it->f, Qno_break_space, 0,
+		  face_id = merge_faces (it->f, Qnobreak_space, 0,
 					 it->face_id);
 
 		  g = it->c = ' ';
@@ -5196,7 +5196,7 @@
 	      /* Handle soft hyphens in the mode where they only get
 		 highlighting.  */
 
-	      if (! EQ (Vshow_nonbreak_escape, Qt)
+	      if (EQ (Vnobreak_char_display, Qt)
 		  && (it->c == 0x8ad || it->c == 0x92d
 		      || it->c == 0xe2d || it->c == 0xf2d))
 		{
@@ -22776,8 +22776,8 @@
   staticpro (&Qtrailing_whitespace);
   Qescape_glyph = intern ("escape-glyph");
   staticpro (&Qescape_glyph);
-  Qno_break_space = intern ("no-break-space");
-  staticpro (&Qno_break_space);
+  Qnobreak_space = intern ("nobreak-space");
+  staticpro (&Qnobreak_space);
   Qimage = intern ("image");
   staticpro (&Qimage);
   QCmap = intern (":map");
@@ -22883,13 +22883,14 @@
 The face used for trailing whitespace is `trailing-whitespace'.  */);
   Vshow_trailing_whitespace = Qnil;
 
-  DEFVAR_LISP ("show-nonbreak-escape", &Vshow_nonbreak_escape,
-    doc: /* *Control highlighting of non-break space and soft hyphen.
-t means highlight the character itself (for non-break space,
-use face `non-break-space'.
+  DEFVAR_LISP ("nobreak-char-display", &Vnobreak_char_display,
+    doc: /* *Control highlighting of nobreak space and soft hyphen.
+t means highlight the character itself (for nobreak space,
+use face `nobreak-space'.
 nil means no highlighting.
-other values mean display the escape glyph before the character.  */);
-  Vshow_nonbreak_escape = Qt;
+other values mean display the escape glyph followed by an ordinary
+space or ordinary hyphen.  */);
+  Vnobreak_char_display = Qt;
 
   DEFVAR_LISP ("void-text-area-pointer", &Vvoid_text_area_pointer,
     doc: /* *The pointer shape to show in void text areas.